@@ -16,24 +16,24 @@ from networking_generic_switch.devices import netmiko_devices
 
 
 class CiscoIos(netmiko_devices.NetmikoSwitch):
-        ADD_NETWORK = (
-            'vlan {segmentation_id}',
-            'name {network_id}',
-        )
+    ADD_NETWORK = (
+        'vlan {segmentation_id}',
+        'name {network_name}',
+    )
 
-        DELETE_NETWORK = (
-            'no vlan {segmentation_id}',
-        )
+    DELETE_NETWORK = (
+        'no vlan {segmentation_id}',
+    )
 
-        PLUG_PORT_TO_NETWORK = (
-            'interface {port}',
-            'switchport mode access',
-            'switchport access vlan {segmentation_id}',
-        )
+    PLUG_PORT_TO_NETWORK = (
+        'interface {port}',
+        'switchport mode access',
+        'switchport access vlan {segmentation_id}',
+    )
 
-        DELETE_PORT = (
-            'interface {port}',
-            'no switchport access vlan {segmentation_id}',
-            'no switchport mode trunk',
-            'switchport trunk allowed vlan none'
-        )
+    DELETE_PORT = (
+        'interface {port}',
+        'no switchport access vlan {segmentation_id}',
+        'no switchport mode trunk',
+        'switchport trunk allowed vlan none'
+    )
