@@ -44,6 +44,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         for switch_info, device_cfg in gsw_devices.items():
             switch = devices.device_manager(device_cfg)
             self.switches[switch_info] = switch
+
         LOG.info('Devices %s have been loaded', self.switches.keys())
         if not self.switches:
             LOG.error('No devices have been loaded')
@@ -453,7 +454,7 @@ class GenericSwitchDriver(api.MechanismDriver):
             port_id = local_link_information[0].get('port_id')
             segments = context.segments_to_bind
             # If segmentation ID is None, set vlan 1
-            segmentation_id = segments[0].get('segmentation_id') or '1'
+            segmentation_id = segments[0].get('segmentation_id') or 1
             provisioning_blocks.add_provisioning_component(
                 context._plugin_context, port['id'], resources.PORT,
                 GENERIC_SWITCH_ENTITY)
@@ -521,7 +522,7 @@ class GenericSwitchDriver(api.MechanismDriver):
             return
         port_id = local_link_information[0].get('port_id')
         # If segmentation ID is None, set vlan 1
-        segmentation_id = network.get('provider:segmentation_id') or '1'
+        segmentation_id = network.get('provider:segmentation_id') or 1
         LOG.debug("Unplugging port {port} on {switch_info} from vlan: "
                   "{segmentation_id}".format(
                       port=port_id,
